@@ -5,7 +5,7 @@ The intention is to provide attractive help output from click, formatted with ri
 customisation required.
 """
 
-__version__ = "1.5.1"
+__version__ = "1.5.2"
 
 from typing import TYPE_CHECKING
 
@@ -24,6 +24,16 @@ from rich_click.rich_group import RichGroup
 if TYPE_CHECKING:
     from click import argument, Choice, option, Path, version_option  # noqa: F401
 
+    __all__ = [
+        "argument",
+        "Choice",
+        "option",
+        "Path",
+        "version_option",
+        "group",
+        "command",
+    ]
+
 
 def group(*args, cls=RichGroup, **kwargs):
     """
